


What are the prerequisites?
-Install Python3
-git clone

Install development dependencies
-make develop
-make build
-make install


What to do before opening a PR? 
make lint
make format
make tests

Please add tests for any new features
make coverage
